<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Parser_ehtml
{
    public function parse($html)
    {
        get_instance()->load->helper('inlineeditor/inline');
        return ehtml($html);
    }
}
