<?php

return [
    'project_modules' => [
        'pages' => [
            'inline_editor' => [
                'label'        => 'Редактор содержимого (Inline editor)',
                'file'         => __DIR__ . '/../docs/inlineeditor_usr.md',
                'position'     => 40,
                'acl_resource' => 'inlineeditor',
                'acl_action'   => 'edit_inlineeditor',
            ],
        ]
    ],
    'developer_docs'  => [
        'pages' => [
            'inlineeditor_dev' => [
                'label'        => 'Редактор содержимого (Inline editor)',
                'file'         => __DIR__ . '/../docs/inlineeditor_dev.md',
                'position'     => 60,
                'acl_resource' => 'inlineeditor',
                'acl_action'   => 'edit_inlineeditor',
            ],
            'core_parsers'     => [
                'pages' => [
                    'inlineeditor_ehtml' => [
                        'label'    => 'ehtml',
                        'file'     => __DIR__ . '/../docs/parsers.md',
                        'position' => 100,
                    ],
                    'inlineeditor_eimg' => [
                        'label'    => 'eimg',
                        'file'     => __DIR__ . '/../docs/parsers.md',
                        'position' => 100,
                    ],
                    'inlineeditor_elabel' => [
                        'label'    => 'elabel',
                        'file'     => __DIR__ . '/../docs/parsers.md',
                        'position' => 100,
                    ],
                    'inlineeditor_etext' => [
                        'label'    => 'etext',
                        'file'     => __DIR__ . '/../docs/parsers.md',
                        'position' => 100,
                    ],
                    'inlineeditor_evideo_yt' => [
                        'label'    => 'evideo_yt',
                        'file'     => __DIR__ . '/../docs/parsers.md',
                        'position' => 100,
                    ],
                ],
            ],
        ]
    ]
];
